Properties Methods Events Config Options Direct Link

# Class Ext.calendar.DateRangeField

Package: | Ext.calendar
Defined In: | DateRangeField.js
Class: | DateRangeField
Extends: | Object

A combination field that includes start and end dates and times, as well as an optional all-day checkbox.

## Config Options

Config Options | Defined By
--- | ---
| toText : String The text to display in between the date/time fields (defaults to 'to') | DateRangeField
| toText : String The text to display as the label for the all day checkbox (defaults to 'All day') | DateRangeField

## Public Properties

This class has no public properties.

## Public Methods

Method | Defined By
--- | ---
| DateRangeField( `Object config` ) Parameters: `config` : Object The config object Returns: void | DateRangeField
| getValue() : Array Returns an array containing the following values in order:<div class="mdetail-params"> DateTime : <div class="sub-des... Returns an array containing the following values in order: `DateTime` : The start date/time `DateTime` : The end date/time `Boolean` : True if the dates are all-day, false if the time values should be used Parameters: None. Returns: `Array` The array of return values | DateRangeField
| setValue( `Array/Date/Object v` ) : void Sets the values to use in the date range. Sets the values to use in the date range. Parameters: `v` : Array/Date/Object The value(s) to set into the field. Valid types are as follows: `Array` : An array containing, in order, a start date, end date and all-day flag. This array should exactly match the return type as specified by getValue. `DateTime` : A single Date object, which will be used for both the start and end dates in the range. The all-day flag will be defaulted to false. `Object` : An object containing properties for StartDate, EndDate and IsAllDay as defined in Ext.calendar.EventMappings. Returns: void | DateRangeField

## Public Events

This class has no public events.